@@ -65,9 +65,3 @@ struct HFSPlusVolumeHeader {
 
 };
 typedef struct HFSPlusVolumeHeader HFSPlusVolumeHeader;
-
-/// read super block and write to image head
-extern void initial_image_hdr(char* device, image_head* image_hdr);
-
-/// readbitmap - cread and heck bitmap, reference dumpe2fs
-extern void readbitmap(char* device, image_head image_hdr, unsigned long* bitmap, int pui);
