@@ -67,7 +67,8 @@ int main(int argc, char **argv) {
 	int			r_size, w_size;		/// read and write size
 	unsigned		cs_size = 0;		/// checksum_size
 	int			cs_reseed = 1;
-	int			start, stop;		/// start, range, stop number for progress bar
+	int			start;
+	unsigned long long      stop;		/// start, range, stop number for progress bar
 	unsigned long *bitmap = NULL;		/// the point for bitmap data
 	int			debug = 0;		/// debug level
 	int			tui = 0;		/// text user interface
@@ -77,6 +78,7 @@ int main(int argc, char **argv) {
 	int			pres = 0;
 	pthread_t		prog_thread;
 	void			*p_result;
+	struct stat st_dev;
 
 	static const char *const bad_sectors_warning_msg =
 		"*************************************************************************\n"
@@ -312,11 +314,20 @@ int main(int argc, char **argv) {
 		log_mesg(0, 0, 1, debug, "done!\n");
 	} else if (opt.ddd){
 
-		if (dfr != 0)
+		if (dfr != 0){
+		    fs_info.device_size = get_partition_size(&dfr);
 		    read_super_blocks(source, &fs_info);
-		else
+		}else{
+		    if (stat(target, &st_dev) != -1) {
+		        if (S_ISBLK(st_dev.st_mode)) 
+			    fs_info.device_size = get_partition_size(&dfw);
+			else
+			    fs_info.device_size = get_free_space(target);
+		    } else {
+			fs_info.device_size = get_free_space(target);
+		    }
 		    read_super_blocks(target, &fs_info);
-
+		}
 		img_opt.checksum_mode = opt.checksum_mode;
 		img_opt.checksum_size = get_checksum_size(opt.checksum_mode, opt.debug);
 		img_opt.blocks_per_checksum = opt.blocks_per_checksum;
@@ -933,7 +944,11 @@ int main(int argc, char **argv) {
 			}
 
 			/// write buffer to target
-			w_size = write_all(&dfw, buffer, blocks_read * block_size, &opt);
+			if (opt.blockfile == 1){
+			    w_size = write_block_file(target, buffer, blocks_read * block_size, copied*block_size, &opt);
+			} else {
+			    w_size = write_all(&dfw, buffer, blocks_read * block_size, &opt);
+			}
 			if (w_size != (int)(blocks_read * block_size)) {
 				if (opt.skip_write_error)
 					log_mesg(0, 0, 1, debug, "skip write block %lli error:%s\n", block_id, strerror(errno));
